@@ -13,8 +13,8 @@ void fullId(char **id, Sint *idLength, Sint *familySizes,
   Sint familySize = 0;
 
   if(*idLength * *loci != *fullIdLength) {
-    PROBLEM "*idLength * *loci = %ld, *fullIdLength = %ld\nThe values need to be equal.\nfullId.cpp key 18\n",
-      (*idLength * *loci), *fullIdLength RECOVER(NULL_ENTRY);
+    PROBLEM "*idLength * *loci = %d, *fullIdLength = %d\nThe values need to be equal.\nfullId.cpp key 18\n",
+      (int)(*idLength * *loci), (int)*fullIdLength RECOVER(NULL_ENTRY);
   }
 
   for(Sint i = 0; i < *familySizesLength; i++) {
@@ -31,12 +31,12 @@ void fullId(char **id, Sint *idLength, Sint *familySizes,
   }
 
   if(*fullIdLength != fullIdIndex) {
-    PROBLEM "*fullIdLength = %ld, fullIdIndex = %ld\nThe values need to be equal.\nfullId.cpp key 29\n",
-      *fullIdLength, fullIdIndex RECOVER(NULL_ENTRY);
+    PROBLEM "*fullIdLength = %d, fullIdIndex = %d\nThe values need to be equal.\nfullId.cpp key 29\n",
+      (int)*fullIdLength, (int)fullIdIndex RECOVER(NULL_ENTRY);
   }
   if(*idLength != baseFamilyIndex) {
-    PROBLEM "*idLength = %ld, baseFamilyIndex = %ld\nThe values need to be equal.\nfullId.cpp key 35\n",
-      *idLength, baseFamilyIndex RECOVER(NULL_ENTRY);
+    PROBLEM "*idLength = %d, baseFamilyIndex = %d\nThe values need to be equal.\nfullId.cpp key 35\n",
+      (int)*idLength, (int)baseFamilyIndex RECOVER(NULL_ENTRY);
   }
 }
 
